==> glpi-10.0.10.tgz: glpi/src/ChangeCost.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2023 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

/**
 * ChangeCost Class
 *
 * @since 0.85
 **/
class ChangeCost extends CommonITILCost
{
   // From CommonDBChild
    public static $itemtype  = 'Change';
    public static $items_id  = 'changes_id';


    public static function canCreate()
    {
        return Session::haveRight('change', UPDATE);
    }


    public static function canView()
    {
        return Session::haveRightsOr('change', [Change::READALL, Change::READMY]);
    }


    public static function canUpdate()
    {
        return Session::haveRight('change', UPDATE);
    }
}

==> glpi-11.0.4.tgz: glpi/src/ChangeCost.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2025 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

/**
 * ChangeCost Class
 *
 * @since 0.85
 **/
class ChangeCost extends CommonITILCost
{
    // From CommonDBChild
    public static $itemtype  = 'Change';
    public static $items_id  = 'changes_id';


    public static function canCreate(): bool
    {
        return Session::haveRight('change', UPDATE);
    }


    public static function canView(): bool
    {
        return Session::haveRightsOr('change', [Change::READALL, Change::READMY]);
    }


    public static function canUpdate(): bool
    {
        return Session::haveRight('change', UPDATE);
    }
}
